@@ -50,7 +50,6 @@ def exec_polqa_test():
         # samplerate = info[3]
         global_result.mosResult = copy.deepcopy(constMosResult)
         startvqt(os.path.abspath(srf), os.path.abspath(tsf), sr)
-        shutil.rmtree(fpath)
         curruslt['result'] = global_result.mosResult
 
         socket = SocketClient(global_result.machost, global_result.PORT)
@@ -59,6 +58,10 @@ def exec_polqa_test():
         socket.sender(curruslt)
         socket.close()
         time.sleep(1)
+        try:
+            shutil.rmtree(fpath)
+        except:
+            print('file was not deleted!')
 
 
 
